@@ -1,3 +1,4 @@
+import os
 from libqtile.lazy import lazy
 from libqtile.config import Key
 from libqtile.utils import guess_terminal
@@ -6,9 +7,9 @@ from stonecharioteer.qtile.inputs import Keyboard, MOD
 from stonecharioteer.utils.displays import get_display_info
 
 
-def configure_keymaps(groups):
+def configure_keymaps(groups, cfg: dict):
     """Configures keymaps"""
-    terminal = "/home/stonecharioteer/.local/bin/kitty"
+    terminal = os.environ.get("QTILE_TERMINAL", guess_terminal())
     Super = [MOD.value]
     SuperShift = [MOD.value, Keyboard.SHIFT.value]
     SuperControl = [MOD.value, Keyboard.CTRL.value]
@@ -75,45 +76,55 @@ def configure_keymaps(groups):
             lazy.spawn("""rofi -modi "drun,run,window,ssh" -show drun"""),
             desc="Spawn a command using a prompt widget",
         ),
+        # find mouse
+        Key(
+            SuperControl,
+            "o",
+            lazy.spawn(
+                'find-cursor -c "#ffaa33" --follow --distance 10 --line-width 1 --size 100 --wait 200 -g -o 1 -O "#88ff33" -t'
+            ),
+        ),
+        Key(
+            Super,
+            "o",
+            lazy.spawn(
+                "scrot -s -e 'mv $f ~/Pictures/ && echo ~/Pictures/$f | xclip -selection clipboard'"
+            ),
+        ),
     ]
 
     for ix, group in enumerate(groups):
+        logger.warning(group.name)
+        key, val = group.name.split(":")
         keys.extend(
             [
                 Key(
                     Super,
-                    str(ix + 1),
+                    key,
                     lazy.group[group.name].toscreen(),
                     desc=f"Switch to group {group.name}",
                 ),
                 Key(
                     SuperShift,
-                    str(ix + 1),
+                    key,
                     lazy.window.togroup(group.name, switch_group=True),
                     desc=f"Switch to & move focussed window to group {group.name}",
                 ),
                 Key(
                     SuperControl,
-                    str(ix + 1),
+                    key,
                     lazy.window.togroup(group.name),
                     desc=f"Move focussed window to group {group.name}",
                 ),
             ]
         )
 
-    display_keys = [
-        ("u", "eDP"),
-        ("m", "DisplayPort-0"),
-        ("y", "DisplayPort-1"),
-        ("i", "HDMI-A-0"),
-    ]
-    try:
-        for ix, (key, display) in enumerate(display_keys):
-            jerry_command = "jerry -m {}".format(display)
-            logger.warning("Monitor = {}".format(display))
-            logger.debug(jerry_command)
-            keys.append(Key(Super, key, lazy.spawn(jerry_command)))
-    except:
-        pass
+    monitors = cfg.get("monitors", [])
+    for monitor in monitors.keys():
+       connector = monitor["connector"]
+       keymap = monitor["keymap"]
+       jerry_command = f"jerry -m {connector}" 
+       logger.warning(f"Monitor = {connector}")
+       keys.append(Key(Super, keymap, lazy.spawn(jerry_command)))
 
     return keys
